Index: wp-admin/edit-comments.php
===================================================================
--- wp-admin/edit-comments.php	(revision 17329)
+++ wp-admin/edit-comments.php	(working copy)
@@ -228,9 +228,9 @@
 <input type="hidden" name="comment_status" value="<?php echo esc_attr($comment_status); ?>" />
 <input type="hidden" name="pagegen_timestamp" value="<?php echo esc_attr(current_time('mysql', 1)); ?>" />
 
-<input type="hidden" name="_total" value="<?php echo esc_attr( $wp_list_table->get_pagination_arg('total_items') ); ?>" />
-<input type="hidden" name="_per_page" value="<?php echo esc_attr( $wp_list_table->get_pagination_arg('per_page') ); ?>" />
-<input type="hidden" name="_page" value="<?php echo esc_attr( $wp_list_table->get_pagination_arg('page') ); ?>" />
+<input type="hidden" autocomplete="off" name="_total" value="<?php echo esc_attr( $wp_list_table->get_pagination_arg('total_items') ); ?>" />
+<input type="hidden" autocomplete="off" name="_per_page" value="<?php echo esc_attr( $wp_list_table->get_pagination_arg('per_page') ); ?>" />
+<input type="hidden" autocomplete="off" name="_page" value="<?php echo esc_attr( $wp_list_table->get_pagination_arg('page') ); ?>" />
 
 <?php if ( isset($_REQUEST['paged']) ) { ?>
 	<input type="hidden" name="paged" value="<?php echo esc_attr( absint( $_REQUEST['paged'] ) ); ?>" />
Index: wp-admin/admin-ajax.php
===================================================================
--- wp-admin/admin-ajax.php	(revision 17329)
+++ wp-admin/admin-ajax.php	(working copy)
@@ -198,47 +198,40 @@
 	if ( !$total || !$per_page || !$page || !$url )
 		die( (string) time() );
 
-	if ( --$total < 0 ) // Take the total from POST and decrement it (since we just deleted one)
-		$total = 0;
+	set_current_screen( 'edit-comments' );
 
-	if ( 0 != $total % $per_page && 1 != mt_rand( 1, $per_page ) ) // Only do the expensive stuff on a page-break, and about 1 other time per page
-		die( (string) time() );
+	$wp_list_table = _get_list_table('WP_Comments_List_Table');
 
-	$post_id = 0;
-	$status = 'total_comments'; // What type of comment count are we looking for?
-	$parsed = parse_url( $url );
-	if ( isset( $parsed['query'] ) ) {
-		parse_str( $parsed['query'], $query_vars );
-		if ( !empty( $query_vars['comment_status'] ) )
-			$status = $query_vars['comment_status'];
-		if ( !empty( $query_vars['p'] ) )
-			$post_id = (int) $query_vars['p'];
-	}
+	$wp_list_table->prepare_items();
 
-	$comment_count = wp_count_comments($post_id);
-	$time = time(); // The time since the last comment count
+	extract( $wp_list_table->_pagination_args );
 
-	if ( isset( $comment_count->$status ) ) // We're looking for a known type of comment count
-		$total = $comment_count->$status;
-	// else use the decremented value from above
-
-	$page_links = paginate_links( array(
-		'base' => add_query_arg( 'apage', '%#%', $url ),
-		'format' => '',
-		'prev_text' => __('&laquo;'),
-		'next_text' => __('&raquo;'),
-		'total' => ceil($total / $per_page),
-		'current' => $page
-	) );
-	$x = new WP_Ajax_Response( array(
+	$response = array(
 		'what' => 'comment',
 		'id' => $comment_id, // here for completeness - not used
 		'supplemental' => array(
-			'pageLinks' => $page_links,
+			'time' => time(),
+/*			'pageLinks' => $wp_list_table->pagination( 'top', false ),
+			'pageLinksBottom' => $wp_list_table->pagination( 'bottom', false ),
+			'l10nTotal' => sprintf( _n( '1 item', '%s items', $total ), number_format_i18n( $total ) ),
 			'total' => $total,
-			'time' => $time
-		)
-	) );
+*/		),
+	);
+
+	if ( isset( $total_items ) ) {
+		$response['supplemental']['total_items'] = $total_items;
+		$response['supplemental']['total_items_i18n'] = sprintf( _n( '1 item', '%s items', $total_items ), number_format_i18n( $total_items ) );
+	}
+
+	if ( isset( $total_pages ) ) {
+		$response['supplemental']['total_pages'] = $total_pages;
+		$response['supplemental']['total_pages_i18n'] = number_format_i18n( $total_pages );
+	}
+
+	// TODO: determine if pagination links need to be updated in case total number of pages change
+ 
+	$x = new WP_Ajax_Response( $response );
+	
 	$x->send();
 }
 
Index: wp-admin/js/edit-comments.dev.js
===================================================================
--- wp-admin/js/edit-comments.dev.js	(revision 17329)
+++ wp-admin/js/edit-comments.dev.js	(working copy)
@@ -4,9 +4,9 @@
 setCommentsList = function() {
 	var totalInput, perPageInput, pageInput, lastConfidentTime = 0, dimAfter, delBefore, updateTotalCount, delAfter;
 
-	totalInput = $('.tablenav input[name="_total"]', '#comments-form');
-	perPageInput = $('.tablenav input[name="_per_page"]', '#comments-form');
-	pageInput = $('.tablenav input[name="_page"]', '#comments-form');
+	totalInput = $('input[name="_total"]', '#comments-form');
+	perPageInput = $('input[name="_per_page"]', '#comments-form');
+	pageInput = $('input[name="_page"]', '#comments-form');
 
 	dimAfter = function( r, settings ) {
 		var c = $('#' + settings.element);
@@ -38,6 +38,7 @@
 		settings.data._per_page = perPageInput.val() || 0;
 		settings.data._page = pageInput.val() || 0;
 		settings.data._url = document.location.href;
+		settings.data.comment_status = $('input[name=comment_status]', '#comments-form').val();
 
 		if ( cl.indexOf(':trash=1') != -1 )
 			action = 'trash';
@@ -85,17 +86,15 @@
 	};
 
 	// Updates the current total (as displayed visibly)
-	updateTotalCount = function( total, time, setConfidentTime ) {
+	updateTotalCount = function( total, time, setConfidentTime, l10nTotal ) {
 		if ( time < lastConfidentTime )
 			return;
 
 		if ( setConfidentTime )
 			lastConfidentTime = time;
 
-		totalInput.val( total.toString() );
-		$('span.total-type-count').each( function() {
-			updateCount( $(this), total );
-		});
+		totalInput.val( total );
+		$('span.displaying-num').text(l10nTotal);
 	};
 
 	function dashboardTotals(n) {
@@ -138,9 +137,9 @@
 		el.html(n);
 	}
 
 	// In admin-ajax.php, we send back the unix time stamp instead of 1 on success
 	delAfter = function( r, settings ) {
-		var total, pageLinks, N, untrash = $(settings.target).parent().is('span.untrash'), unspam = $(settings.target).parent().is('span.unspam'), spam, trash;
+		var total, pageLinks, N, untrash = $(settings.target).parent().is('span.untrash'), unspam = $(settings.target).parent().is('span.unspam'), spam, trash, parsedResponse, tablenav;
 
 		function getUpdate(s) {
 			if ( $(settings.target).parent().is('span.' + s) )
@@ -191,20 +190,20 @@
 			if ( total < 0 )
 				total = 0;
 
-			if ( ( 'object' == typeof r ) && lastConfidentTime < settings.parsed.responses[0].supplemental.time ) {
-				pageLinks = settings.parsed.responses[0].supplemental.pageLinks || '';
-				if ( $.trim( pageLinks ) )
-					$('.tablenav-pages').find( '.page-numbers' ).remove().end().append( $( pageLinks ) );
-				else
-					$('.tablenav-pages').find( '.page-numbers' ).remove();
-
-				updateTotalCount( total, settings.parsed.responses[0].supplemental.time, true );
-			} else {
-				updateTotalCount( total, r, false );
+			if 	( ( 'object' == typeof r ) && lastConfidentTime < settings.parsed.responses[0].supplemental.time ) {
+				parsedResponse = settings.parsed.responses[0].supplemental;
+				tablenav = $('.tablenav-pages');
+				$('.displaying-num').html(parsedResponse.total_items_i18n);
+				$('.total-pages').html(parsedResponse.total_pages_i18n);
+				if ( parsedResponse.total_pages > 1 )
+					tablenav.removeClass('one-page');
+				updateTotalCount( parsedResponse.total_items, parsedResponse.time, true, parsedResponse.total_items_i18n );
+				tablenav.find('.first-page, .prev-page').toggleClass('disabled', 1 == $('.current-page').val());
+				tablenav.find('.next-page, .last-page').toggleClass('disabled', parsedResponse.total_pages == $('.current-page').val());
+				// update last page href: tablenav.find('.last-page.').attr('href').val( $.query.SET('paged', parsedResponse.total_pages ) );			
 			}
 		}
 
-
 		if ( ! theExtraList || theExtraList.size() == 0 || theExtraList.children().size() == 0 || untrash || unspam ) {
 			return;
 		}
@@ -138,9 +137,9 @@
 	}
 
-	// In admin-ajax.php, we send back the unix time stamp instead of 1 on success
+	// In admin-ajax.php, we send back the unix time stamp as well as localized total items on success
 	delAfter = function( r, settings ) {
